@@ -39,6 +39,7 @@
 #include "nautilus-icon-view.h"
 #include "nautilus-image-properties-page.h"
 #include "nautilus-list-view.h"
+#include "nautilus-previewer.h"
 #include "nautilus-progress-ui-handler.h"
 #include "nautilus-self-check-functions.h"
 #include "nautilus-window.h"
@@ -1043,25 +1044,6 @@ nautilus_application_local_command_line (GApplication *application,
 static void
 init_icons_and_styles (void)
 {
-	GtkCssProvider *provider;
-	GError *error = NULL;
-
-	/* add our custom CSS provider */
-	provider = gtk_css_provider_new ();
-	gtk_css_provider_load_from_path (provider,
-					 NAUTILUS_DATADIR G_DIR_SEPARATOR_S "nautilus.css", &error);
-
-	if (error != NULL) {
-		g_warning ("Can't parse Nautilus' CSS custom description: %s\n", error->message);
-		g_error_free (error);
-	} else {
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-							   GTK_STYLE_PROVIDER (provider),
-							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	}
-
-	g_object_unref (provider);
-
 	/* initialize search path for custom icons */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   NAUTILUS_DATADIR G_DIR_SEPARATOR_S "icons");
@@ -1143,6 +1125,9 @@ nautilus_application_startup (GApplication *app)
 	 */
 	G_APPLICATION_CLASS (nautilus_application_parent_class)->startup (app);
 
+	/* initialize the previewer singleton */
+	nautilus_previewer_get_singleton ();
+
 	/* create an undo manager */
 	self->undo_manager = nautilus_undo_manager_new ();
 
@@ -1206,11 +1191,28 @@ nautilus_application_quit_mainloop (GApplication *app)
 	G_APPLICATION_CLASS (nautilus_application_parent_class)->quit_mainloop (app);
 }
 
+static void
+nautilus_application_window_removed (GtkApplication *app,
+				     GtkWindow *window)
+{
+	NautilusPreviewer *previewer;
+
+	/* chain to parent */
+	GTK_APPLICATION_CLASS (nautilus_application_parent_class)->window_removed (app, window);
+
+	/* if this was the last window, close the previewer */
+	if (g_list_length (gtk_application_get_windows (app)) == 0) {
+		previewer = nautilus_previewer_get_singleton ();
+		nautilus_previewer_call_close (previewer);
+	}
+}
+
 static void
 nautilus_application_class_init (NautilusApplicationClass *class)
 {
         GObjectClass *object_class;
 	GApplicationClass *application_class;
+	GtkApplicationClass *gtkapp_class;
 
         object_class = G_OBJECT_CLASS (class);
 	object_class->constructor = nautilus_application_constructor;
@@ -1222,6 +1224,9 @@ nautilus_application_class_init (NautilusApplicationClass *class)
 	application_class->open = nautilus_application_open;
 	application_class->local_command_line = nautilus_application_local_command_line;
 
+	gtkapp_class = GTK_APPLICATION_CLASS (class);
+	gtkapp_class->window_removed = nautilus_application_window_removed;
+
 	g_type_class_add_private (class, sizeof (NautilusApplication));
 }
 
